@@ -133,6 +133,8 @@ class SoptGateway(BaseGateway):
     vn.py用于对接期权CTP柜台的交易接口。
     """
 
+    default_name: str = "SOPT"
+
     default_setting = {
         "用户名": "",
         "密码": "",
@@ -145,7 +147,7 @@ class SoptGateway(BaseGateway):
 
     exchanges: List[str] = list(EXCHANGE_SOPT2VT.values())
 
-    def __init__(self, event_engine: EventEngine, gateway_name: str = "SOPT") -> None:
+    def __init__(self, event_engine: EventEngine, gateway_name: str) -> None:
         """构造函数"""
         super().__init__(event_engine, gateway_name)
 
